API Reference
=============

This section contains the complete API reference for oduit.

Core Modules
------------

.. toctree::
   :maxdepth: 2

   process_manager
   config_loader
   odoo_operations
   odoo_code_executor
   module_manager
   demo_process_manager

Command Line Interface
----------------------

.. toctree::
   :maxdepth: 2

   api/cli_typer
   api/cli_types

Utilities
---------

.. toctree::
   :maxdepth: 2

   operation_result
   output
   exceptions
   builders
   utils

Complete API
------------

.. toctree::
   :maxdepth: 1

   modules
